magneticalc.Theme.Theme

# ``magneticalc`.`Theme`.`Theme``

class documentation

`class Theme:`

View In Hierarchy

Theme class.

Class Variable | `DarkColor` | Undocumented
Class Variable | `DefaultFontFace` | Undocumented
Class Variable | `DialogTextColor` | Undocumented
Class Variable | `FailureColor` | Undocumented
Class Variable | `LiteColor` | Undocumented
Class Variable | `MainColor` | Undocumented
Class Variable | `QuestionColor` | Undocumented
Class Variable | `SuccessColor` | Undocumented

DarkColor: `str` =

Undocumented

DefaultFontFace: `str` =

Undocumented

DialogTextColor: `str` =

Undocumented

FailureColor: `str` =

Undocumented

LiteColor: `str` =

Undocumented

MainColor: `str` =

Undocumented

QuestionColor: `str` =

Undocumented

SuccessColor: `str` =

Undocumented